The Array class (``zarr.core``)
===============================
.. module:: zarr.core

.. autoclass:: Array

    .. automethod:: __getitem__
    .. automethod:: __setitem__
    .. automethod:: resize
    .. automethod:: append
